#### General

Node ID
  {$ ctrl.node.uuid | noValue $}
Chassis ID
  {$ ctrl.node.chassis_uuid | noValue $}
Created At
  {$ ctrl.node.created_at | date:'medium' | noValue $}

#### Ports

{$ 'Create port' | translate $} {$ 'Delete ports' | translate $}
| MAC Address | Properties | Actions
--- | --- | --- | ---
| {$ port.address $} | pxe_enabled: {$ port.pxe_enabled $} {$ propertyObject $}: {$ id $}: {$ value $} {$ value $} | {$ ::'Edit port' | translate $} {$ ::'Delete port' | translate $}

#### Driver Info

Driver
  {$ ctrl.node.driver | noValue $}
SSH Address
  {$ ctrl.node.driver_info.ssh_address | noValue $}
SSH Port
  {$ ctrl.node.driver_info.ssh_port | noValue $}
SSH Username
  {$ ctrl.node.driver_info.ssh_username | noValue $}
SSH Key File
  {$ ssh_key_filename | noValue $}
SSH Password
  {$ ssh_password | noValue $}
SSH Key Contents
  {$ ssh_key_contents | noValue $}
SSH terminal port
  {$ ctrl.node.driver_info.ssh_terminal_port | noValue $}
Virtualization Software
  {$ ctrl.node.driver_info.ssh_virt_type | noValue $}
Deploy Kernel
  {$ ctrl.node.driver_info.deploy_kernel | noValue $} {$ ctrl.node.driver_info.deploy_kernel | noValue $}
Deploy Ramdisk
  {$ ctrl.node.driver_info.deploy_ramdisk | noValue $} {$ ctrl.node.driver_info.deploy_ramdisk | noValue $}

{$ id $}
  {$ value $}

#### Driver Validation

Interface | Valid | Reason
--- | --- | ---
{$ item.id $} |  | {$ item.reason $}

#### Properties

{$ propertyName $}
  {$ propertyValue | noValue $}

#### Instance Info

Instance Name
  {$ ctrl.node.instance_info.display_name | noValue $}
Ramdisk
  {$ ctrl.node.instance_info.ramdisk | noValue $}
Kernel
  {$ ctrl.node.instance_info.kernel | noValue $}
Image Source
  {$ ctrl.node.instance_info.image_source | noValue $}
Root GB
  {$ ctrl.node.instance_info.root_gb | noValue $}

{$ id $}
  {$ value | noValue $}

#### Extra

{$ propertyName $}
  {$ propertyValue | noValue $}